@@ -5,6 +5,8 @@ import json
 import os
 import string
 
+import _fireinfo
+
 import cpu
 import device
 import hypervisor
@@ -172,6 +174,11 @@ class System(object):
 			id = read_from_file(os.path.join(SYS_CLASS_DMI, file)) or ""
 			ids.append(id)
 
+		# Use serial number from root disk (if available)
+		root_disk_serial = self.root_disk_serial
+		if root_disk_serial:
+			ids.append(root_disk_serial)
+
 		# As last resort, we use the UUID from pakfire.
 		if not ids:
 			id = read_from_file("/opt/pakfire/db/uuid") or ""
@@ -248,6 +255,10 @@ class System(object):
 			return
 		with open(path, "r") as f:
 			return int(f.readline())*512/1024
+
+	@property
+	def root_disk_serial(self):
+		return _fireinfo.get_harddisk_serial("/dev/%s" % self.root_disk).rstrip()
 					
 	def scan(self):
 		toscan = (("/sys/bus/pci/devices", device.PCIDevice),
